# Rationale and motivation for running NEMO-eNATL60 simulations

The upcoming Surface Water and Ocean Topography (SWOT) radar altimeter mission, to be launched in 2022, will provide an opportunity for better observing ocean surface processes at fine scales (<200km) and for better understanding their impact on larger scales oceanic flows. Combined with other measurements from conventional nadir-looking altimeters, SWOT data will be used for estimating sea surface height (SSH) and surface geostrophic currents at global scale and for improving the spatial resolution of gridded SSH products. It is expected that the above data products will help to better quantify energy exchanges across scales in the ocean and also to estimate the rate and the distribution of vertical exchanges between the interior ocean and ocean surface layers, both of which being key objectives for SWOT mission.

But because of the innovative nature of SWOT measurements, meeting SWOT mission scientific objectives requires the design of specific inversion techniques. Preparing the inversion techniques for the future SWOT data not only requires knowledge on the sampling and errors patterns but also requires information as to typical SSH scenes that will be measured during the mission. Indeed the signal-to-noise-ratio (SNR) of SWOT measurements will strongly depend on the amplitude and the scale content of the scenes that will be observed. Realistic a priori estimates of SSH scenes are therefore essential for designing inversion techniques for SWOT measurement and for documenting to what extent SWOT measurements, given their sampling and error patterns, will allow to estimate SSH and ocean surface currents on the instrument swath. 

Numerical ocean models, in conjunction with observation simulators, can be used for providing a range of possible observational scenes for preparing satellite missions. Several groups from SWOT Science Team have embarked on this challenge of running high resolution ocean models at basin to global scale in preparation for SWOT mission and to the benefit of the wider scientific community. Basin-to-global-scale submesoscale permitting simulations form also indeed a unique scientific material for studying cross-scale interactions in the ocean, but it should be aknowledged that only a small number of groups can leverage the computational resources and the expertise for running ocean models. This is why the exploration of the above model datasets is generally distributed within a wider community so that the analysis is shared among different groups.

The twin eNATL60 simulations have been designed with this double objective of : 
 - (i) providing virtual observations for preparing the exploitation of SWOT ocean data and 
 - (ii) providing material for studying cross-scale interactions in the open ocean at mid-latitudes. 

The model configuration has been defined in order to model as accurately as possible surface signature of oceanic motions of scales down to 15km in line with the expected effective resolution of SWOT ocean data. The choice of the model horizontal and vertical resolution derives from this objective. A particular emphasis has also been put on the representation of high frequency motions associated with internal tides as several studies suggest that these signals will be prominent in SWOT data at scale <100km. Finally, we have made the choice to formulate twin experiments in order to allow to quantify the impact of high frequency wave motions on larger scale turbulence. 



## License
This work is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by/4.0/">Creative Commons Attribution 4.0 International License</a>.
